@@ -719,6 +719,32 @@ public:
     static void uuid(char *string);
 
     static String uuid(void);
+
+    template <class T>
+    inline static T value(void) {
+        T tmp;
+        Random::key(reinterpret_cast<unsigned char *>(&tmp), sizeof(tmp));
+        return tmp;
+    }
+
+    template <class T>
+    inline static T value(T max) {
+        T slice;
+        T value;
+
+        value = 0xffffffff;
+        slice = 0xffffffff / max;
+        while(value >= max) {
+            value = Random::value<T>() / slice;
+        }
+        return value;
+    }
+
+    template <class T>
+    inline static T value(T min, T max)
+    {
+        return min + Random::value<T>(max - min);
+    }    
 };
 
 /**
@@ -982,7 +1008,6 @@ public:
         {return S;}
 };
 
-
 #endif
 
 } // namespace ucommon
